/* phokus.css

   This style sheet is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2, or (at
   your option) any later version.

   This style sheet is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this style sheet; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
   USA.
*/

/* yup, this style sheet was definitely stolen from typo.  that's the
   MIT license for ya :) 

Original author:

*******************************************************************************
*                                                                             *
* Typo Theme  :  Phokus                                                       *
* Author      :  John Serris (a.k.a JB)                                       *
* Web         :  http://phonophunk.com/                                       *
* E-mail      :  phonophunk ( at ) gmail ( dot ) ( com )                      *
* Modified    :  04-DEC-2005                                                  *
*                                                                             *
******************************************************************************/

* {
	margin: 0;
	padding: 0;
}
html, body {
       background-color: #4f4f4f;
       color: #fff;
}

/* Layout
*******************************************************************************/

#page {
	background-color: #4f4f4f;
	font-size: 1em;
	margin: 0 auto;
        width: 758px;

}
#header {
	background: #1381d4 url(images/phokus/hd-bg-02.gif) no-repeat;
	height: 168px;
	margin: 0 4px;
	position: relative;
	width: 750px;
}

#content {
	background:  url(images/phokus/mn-bg.gif) repeat-y;
	color: #444;
	margin: 0 4px 0px 203px;
	padding: 0;
	width: 551px;
}
#sidebar {
	background: #696969 url(images/phokus/sb-bg.gif) repeat-y;
	color: #fff;
	float: left;
	font-size: .9em;
	margin: 0 0 4px 4px;
	padding: 0;
	width: 199px;
}
#footer {
	background: #696969 url(images/phokus/ft-top.gif) no-repeat;
	color: #aaa;
	font-size: .8em;
        margin-left: 203px;
	text-align: center;
	width: 551px;
        clear: left;
}

#error { background: #fdd; color: #f00; font-weight: bold; padding: .5em 0 .5em 2em;}

/* General
*******************************************************************************/


h1 { 
     font-family: "cmr10", "Lucida Grande", "Century Gothic", Verdana, Arial, Helvetica, sans-serif;
 }


.post_title h2 {
	color: #fff;
	font-family: "Lucida Grande", "Century Gothic", Verdana, Arial, Helvetica, sans-serif;
	font-weight: normal;
}

.post_title p { 
                color: #fff;
                }
h3,
h4,
h5,
h6 {
	color: #777;
	font-family: "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
	font-size: 1.5em;
	margin: 1em 0;
}
h4 {
	font-size: 1.2em;
}
h5 {
	font-size: 1em;
}
h6 {
	font-size: 1em;
	font-style: italic;
}
a {
	color: #0a78cb;
}

h1 a,
h2 a {
	background: none;
	border: none;
	color: #fff;
	text-decoration: none;
}
h1 a:hover,
h2 a:hover {
	background: none;
	border: none;
	color: #c2e5ff;
	text-decoration: none;
}
img {
	border: none;
	max-width: 501px;
}
p,
ul,
ol,
dl
{
	margin: 1em 0;
}
ul ul,
ol ol {
	margin: 0;
}
li {
	list-style-position: inside;
}
li li {
	margin: 0 0 0 1em;
}
ul li {
	background: url(images/phokus/blt-01.gif) no-repeat 0 .2em;
	list-style: none;
	padding: 0 0 0 16px;
}
blockquote {
	background: #f5f5f5;
	border: 1px solid #eee;
	font-style: italic;
	margin: 1em;
	padding: 0 1em;
}
code {
	white-space: pre;
	background: #c2e5ff;
}
pre {
        white-space: pre;
	background: #0a0a0a;
	color: #cccccc;
	font-family: monospace;
        font-size: 93%;
	border: 1px solid #555555;
	overflow: auto;
	padding: 10px;
	width: 479px;
}
input,
textarea {
	font-family: "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
	font-size: 1em;
}

/* Header
*******************************************************************************/

h1 {
	bottom: 50%;
	font-size: 2.8em;
	margin: 0 0 5px 40px;
	position: absolute;
}
#header small {
	color: #c2e5ff;
	font-size: .9em;
	margin: 5px 0 0 40px;
	position: absolute;
	top: 50%;
}

/* Posts
*******************************************************************************/

.mini_post_title { 
                   margin-top: -1.1em;
   background: url(images/phokus/mini-top.gif) no-repeat 100% 0%;
 }
.mini_post_title p { 
                     font-size: 1.1em;
                     font-weight: bold;
                     padding-top: 1em;
                     padding-left: 1em;
 }
.mini_post {  
   background: url(images/phokus/mn-bottom.gif) no-repeat 0 100%;
 }

.mini_body { 
             margin-left: 2em; margin-right: 2em; 
             padding-bottom: 1em;
 }

.mini_body .more { 
                   text-align: right;
 }


.post {
	background: url(images/phokus/mn-bottom.gif) no-repeat 0 100%;
	color: #444;
	padding: 0 25px 9px;
	position: relative;
	width: 501px;
}

.post_title {
	background: #0a78cb url(images/phokus/mn-top.gif) no-repeat 0 0;
	margin: 0 0 0 -25px;
	padding: 15px 34px 12px 20px;
	width: 497px;
}
h2 { 
	font-size: 2.2em;

 }
.post_title p { 
                padding: 0; margin: 0;
 }

.post_info
 {
	background: #c2e5ff url(images/phokus/meta-top.gif) no-repeat;
	color: #0a78cb;
	font-size: .9em;
	margin: 0 0 15px -25px;
	padding: 10px 25px 10px 25px;
	position: relative;
	width: 501px;
}

.post_info p { 
               margin: 0; padding: 2px; text-decoration: none;
 }

.last_modified { 
                 font-size: 70%;
 }

#comments .comments_header, #comments .after { 
   background: none;
                         
 }

.post_links {
              float: right;
              text-align: right;
              padding-bottom: 0;
              margin-top: -.3em;
              width: 20em;
}

.comment { 
   background-color: #eeffff;
 }

.comment_header p.title {  margin: 0; padding-left: 3px; color: #fff; font-weight: bold; background-color: #1381d4; }
.comment_header p.info { margin: 0; padding-left: 2px; color: #000; font-weight: bold; font-size: 80%; background-color: #c2e5ff;
 }
.comment_footer{  margin: 0; padding-left: 3px; font-size: 80%; font-weight: bold;}

/* search */
.search_results { 
    padding: 2em;
   background: url(images/phokus/mini-top.gif) no-repeat 100% 0%;
 }

.after { 
   background: url(images/phokus/mn-bottom.gif) no-repeat 0 100%;
 }

#nav_footer p { 
 padding-top: 1em;
 padding-bottom: 1em;
 margin-bottom: -1em;
 }
#nav_footer { 
   margin-top: -1em;
   text-align: center;
   background: url(images/phokus/mini-top.gif) no-repeat 100% 0%;
      
 }
.comments_header { 
/*   margin-top: -1.2em;*/
   padding-top: .1em;
   background: url(images/phokus/mini-top.gif) no-repeat 100% 0%;
 }
.comments_header p {
                     font-size: 70%;
                     padding-left: 2em;
                     padding-right: 2em;
                     margin-bottom: -1em;
                     text-align: center;
 }
#post_comment, #comments, #login, #feeds, #users, #tag_cloud { 
       padding: 2em;
   background: url(images/phokus/mini-top.gif) no-repeat 100% 0%;
 }


#button {
	background: #0a78cb url(images/phokus/lb-top.gif) no-repeat 0 -2px;
	border: 2px solid #0a78cb;
	color: #fff;
	font-weight: bold;
	padding: 3px;
}

/* Side Bar
*******************************************************************************/

#sidebar h3 {
	background: url(images/phokus/sb-top.gif) no-repeat;
	color: #fff;
	display: block;
	font-family: "Lucida Grande", Verdana, Arial, Helvetica, sans-serif;
	font-size: 1em;
	font-weight: bold;
	margin: 0 0 5px 0;
	padding: 15px 34px 0 15px;
	position: relative;
	text-transform: uppercase;
	width: 150px;
}
#sidebar .box {
	background: url(images/phokus/sb-bottom.gif) no-repeat 0 100%;
        padding-bottom: 15px;
}

#sidebar ul,
#sidebar li {
	background: none;
	list-style: none;
	margin: 0;
	padding: 0;
	position: relative;
}
#sidebar a, #sidebar b {
	border: none;
	color: #ddd;
}


#sidebar li a, #sidebar li b {
	display: block;
	padding: 6px 15px 6px 15px;
	border: none;
	width: 169px;
	overflow: hidden;
}

#sidebar p { 
        width: 169px;
        overflow: hidden;
        padding: 6px 15px 5px 15px;
 }
#sidebar li a:hover, #sidebar li b {
	background: #fff url(images/phokus/sb-a-bg.gif) repeat-y 0 50%;
	color: #2392e4;
}

#sidebar li a b {
    margin: -6px -15px;
}

/* Footer */

#footer p {
	font: bold .9em/1em Arial, Helvetica, sans-serif;
	letter-spacing: 1px;
	padding-top: 1em;
	text-transform: uppercase;
}
#footer a {
	border-color: #888;
	color: #ccc;
}

/* Link icons
*******************************************************************************/

.link-ico {
	border: none;
	display: inline-table;
	position: relative;
	padding: 0;
	top: 5px;
	width: 17px;
}
.link-ico span {
	background-color: #fff;
	background-repeat: no-repeat;
	display: table-cell;
	height: 1.5em;
	width: 17px;
}
#sidebar .link-ico {
	padding: 0;
	width: 19px;
}
#sidebar .link-ico span {
	background-color: transparent;
	width: 19px;
}
#commentList .author-details .link-ico span {
	background-color: #f5f5f5;
}
.meta .link-ico span {
	background-color: #c2e5ff;
}
.ico-feed {
	background-image: url(images/phokus/ico-feed.gif);
}
.ico-external {
	background-image: url(images/phokus/ico-external.gif);
}

/* Fixes
*******************************************************************************/

#content textarea, #content input[type=text] {
  width: 481px;
  }

